@@ -261,7 +261,7 @@ double precision refractive(nw), k_Cab(nw), k_Car(nw), k_Brown(nw), k_Cw(nw), k_
 2470,2471,2472,2473,2474,2475,2476,2477,2478,2479,&
 2480,2481,2482,2483,2484,2485,2486,2487,2488,2489,&
 2490,2491,2492,2493,2494,2495,2496,2497,2498,2499,&
-2500./
+2500/
 
 ! ********************************************************************************
 ! Refractive index
